#!/bin/ksh
#
# ATMS/CrIS test case

[ $AAPP_PREFIX ] || { echo "AAPP_PREFIX is not defined"; exit; }
[ -d "$AAPP_PREFIX" ] || { echo "AAPP_PREFIX is not a directory"; exit; }

. "$AAPP_PREFIX/ATOVS_CONF"               #AAPP environment

SDR=$PWD/SDR
level1=$PWD/level1
work=$PWD/work
mkdir -p $work $level1
rm -f $work/*.l1c
cd $SDR

#----Decode the ATMS SDR files

atmssdrfiles=$(ls SATMS*.h5)
for sdrfile in $atmssdrfiles; do
  set $(IFS=_; echo $sdrfile)
  satellite_date_time=${2}_${3}_${4}_${5}
  tdrfile=$(ls TATMS_${satellite_date_time}*.h5)
  geofile=$(ls GATMO_${satellite_date_time}*.h5)
  atms_sdr -g $geofile $sdrfile $tdrfile || { echo atms_sdr failed; exit 1; }
  mv *.l1c $work
done

#----Decode the CRIS SDR files

crissdrfiles=$(ls SCRIS*.h5)
for sdrfile in $crissdrfiles; do
  set $(IFS=_; echo $sdrfile)
  satellite_date_time=${2}_${3}_${4}_${5}
  geofile=$(ls GCRSO_${satellite_date_time}*.h5)
  cris_sdr -g $geofile $sdrfile || { echo cris_sdr failed; exit 1; }
  mv *.l1c $work
done

#----Combine the individual granules

cd $work
rm -f atms.l1c
combine_1c SATMS*.l1c || { echo combine_1c failed for ATMS; exit 1; }

firstfile=$(ls SATMS*.l1c | head -1)
lastfile=$(ls -r SATMS*.l1c | head -1)
combinedfile_atms=${firstfile%_e*}_e${lastfile#*_e}
rm SATMS*.l1c
mv atms.l1c $combinedfile_atms

rm -f cris.l1c
combine_1c SCRIS*.l1c || { echo combine_1c failed for CRIS; exit 1; }

firstfile=$(ls SCRIS*.l1c | head -1)
lastfile=$(ls -r SCRIS*.l1c | head -1)
combinedfile_cris=${firstfile%_e*}_e${lastfile#*_e}
rm SCRIS*.l1c
mv cris.l1c $combinedfile_cris

#----ATMS spatial filtering (if required)

outfile_atms=${combinedfile_atms%%_c*}_filtered.l1c   #cut the creation time
atms_beamwidth $combinedfile_atms $outfile_atms

#----CRIS channel selection

outfile_cris=${combinedfile_cris%%_c*}_channels.l1c   #cut the creation time
cris_channels $combinedfile_cris $outfile_cris

#----Map ATMS to CrIS

atovpp -g CRIS -i "ATMS CRIS" -f "$outfile_atms $combinedfile_cris"
atovpp -g CRIS -i "ATMS CRIS" -f "$outfile_atms $outfile_cris"

mv *.l1c *.l1d $level1
echo "$0 finished"

